#!/bin/bash
###############################################################################
#                             RUN NEMO
###############################################################################
#SBATCH --ntasks 1
#SBATCH --job-name ORCA1_OFF_PISCES-1
#SBATCH --output /home/bsc32/bsc32340/logs/log.nemo_1_%j.out
#SBATCH --error /home/bsc32/bsc32340/logs/log.nemo_1_%j.err
##SBATCH -R "span[ptile=24]"
#SBATCH --time 00:59:00
#SBATCH --qos=debug


# Finding Job id
   RN_JOBID=${SLURM_JOB_ID:-$LSB_JOBID}


# Creating rundir
   EXECDIR=${SCRATCH}/runs/${RN_JOBID}
   mkdir -p ${EXECDIR}


# Copying executable, namelist and xmls to execdir
   cp ./nemo $EXECDIR
   cp namelist_* $EXECDIR
   cp *xml $EXECDIR


# Update link to latest
   rm ${SCRATCH}/runs/latest
   ln -s ${SCRATCH}/runs/${RN_JOBID}/ ${SCRATCH}/runs/latest


# Entering rundir
   cd ${EXECDIR}


# Linking wrappers, inidata, xios_server.exe and extrae xmls
   #ln -s ~/extrae/nemo_wrapper.sh .
   #ln -s ~/extrae/xios_wrapper.sh .
   ln -s /gpfs/projects/bsc32/repository/pisces_off/ORCA1_OFF_PISCES_83138_2015/* .
   ln -s /gpfs/projects/bsc32/models/pisces_off/xios-2.5/bin/xios_server.exe .
   #cp  ~/extrae/extrae* .


# Changing the number of steps (if activated)
   if [[ False == True ]];then
      sed -ri 's/(.)(nn_itend)(.*)/   \2    =    ''   /' namelist_cfg
      sed -ri 's/(.)(nn_itend)(.*)/   \2    =    ''   /' namelist_ref
   fi


# Setting jpni and jpnj parameters (if activated)
   JPNI=0
   JPNJ=0

   if [[ False == True ]]; then
      SQ=$(echo "sqrt(1)" | bc)
      for i in $(seq 1 1  $(($SQ)));do
         for j in $(seq 1 1 1);do
            if [[ $(($i * $j)) -eq 1 ]];then
               JPNI=$i
               JPNJ=$j
            fi
         done
      done
   fi
   
   if [[ False == True ]]; then
    sed -ri 's/(.)(jpni )(.*)(!)(.*)/  \2 =  '$JPNI'  \4 \5/' namelist_ref 
    sed -ri 's/(.)(jpnj )(.*)(!)(.*)/  \2 =  '$JPNJ'  \4 \5/' namelist_ref 
    sed -ri 's/(.)(jpni )(.*)(!)(.*)/  \2 =  '$JPNI'  \4 \5/' namelist_cfg 
    sed -ri 's/(.)(jpnj )(.*)(!)(.*)/  \2 =  '$JPNJ'  \4 \5/' namelist_cfg 
   fi 

# Linking the logs
   ln -sf /home/bsc32/bsc32340/logs/log.nemo_1_${RN_JOBID}.out /home/bsc32/bsc32340/logs/latest.out
   ln -sf /home/bsc32/bsc32340/logs/log.nemo_1_${RN_JOBID}.err /home/bsc32/bsc32340/logs/latest.err
   
   ln -sf /home/bsc32/bsc32340/logs/log.nemo_1_${RN_JOBID}.out log.out
   ln -sf /home/bsc32/bsc32340/logs/log.nemo_1_${RN_JOBID}.err log.err
   
   
# Creating a file with information about the experiment in the rundir
   
   echo /gpfs/projects/bsc32/models/pisces_off/NEMO-4.0.1/cfgs/P1D/EXP00 > expdef.txt
   echo "CONFIG:" ORCA1_OFF_PISCES >> expdef.txt
   echo "NEMO: 1  XIOS: 0" >> expdef.txt
   echo "SCRIPT:" "./rn " >> expdef.txt
   echo "IMPI: impi EXTRAE: False" >> expdef.txt
   
# Exporting the MPI library used (used by the wrapper)
   #export myMPI=impi
   XIOS=False
   
   
# Export extrae variable (for the wrapper to know if it is activated)
   export EXTRAE=False
   
   
# Source the proper environment for the run
   module load impi/2017.4
   module load netcdf/4.2
   module load hdf5/1.8.19

# Executing ELPiN
   if [[ False == True ]]; then
     /gpfs/projects/bsc32/models/pisces_off/ELPiN/ELPiNv2.cmd 1
   fi
   
# Replace the number of resources used for NEMO and XIOS
   NEMO_PROC=1
   XIOS_PROC=0
   NEMO_NODES=1
   XIOS_NODES=0
   
   
   
# If extrae is used, create the function file for extrae.
   if [[ $EXTRAE == True ]];then
       ~//home/bsc32/bsc32340/scripts/make_functions_for_xml.cmd ./nemo ~//home/bsc32/bsc32340/scripts/functions.txt
   fi
   
   
# Modify the iodef.xml file to select if using or not servers.
   if [[ False == True ]]; then
       XSERVER=true
   else
       XSERVER=false
   fi
   
   sed -ri 's/(.*)(using_server)(.*)(true|false)(.*)/\1\2\3'$XSERVER'\5/' iodef.xml
   
   
# Launch command
   if [[ $XIOS == False ]];then
      EXEC="time mpirun -np $NEMO_PROC ./nemo"
   else
      EXEC="time mpirun -np $XIOS_PROC ./xios_server.exe : -np $NEMO_PROC ./nemo"
   fi
   
# Register execution command and tag in the expdef.txt file 
   echo "RUN:" $EXEC >> expdef.txt
   echo TAG:  >> expdef.txt
   
   
# Actual execution
   eval $EXEC
   
   
# Simulation finished
   echo "done"
   
   
# If not indicated, remove .nc outputs
   if [[ True == False ]]; then
     rm -f  *restart*
     rm -f *.nc
   fi
   
# If extrae was activated, launch merge job
   if [[ $EXTRAE == True ]]; then
       sbatch ~/scripts/smpi2prv.cmd
   fi

